#include <sta/bus/spi/device.hpp>

#include <sta/debug/assert.hpp>


namespace sta
{
    SPIDevice::SPIDevice(SPI * intf, GpioPin * csPin)
        : Device{intf}, intf_{intf}, csPin_{csPin}
    {
        STA_ASSERT(intf != nullptr);
        STA_ASSERT(csPin != nullptr);
    }

    void SPIDevice::transfer(const uint8_t * txBuffer, uint8_t * rxBuffer, size_t size)
	{
		STA_ASSERT(intf_->isAcquired());
		STA_ASSERT(txBuffer != nullptr);
		STA_ASSERT(rxBuffer != nullptr);

		intf_->transfer(txBuffer, rxBuffer, size);
	}

    const SPISettings & SPIDevice::settings() const
    {
        return intf_->settings();
    }

    void SPIDevice::select()
    {
        csPin_->setState(GpioPinState::GPIO_LOW);
    }

    void SPIDevice::deselect()
    {
        csPin_->setState(GpioPinState::GPIO_HIGH);
    }
} // namespace sta
